description: Get or set the dataset Description

View source: R/description.R

descriptionR Documentation

Get or set the dataset Description

Description

Get or set the optional Description property as an attribute on a dataset object.

Usage

description(x)

description(x, overwrite = FALSE) <- value

Arguments

x

A dataset object created with dataset_df() or as_dataset_df().

overwrite

Logical. If TRUE, will overwrite any existing description. If FALSE (default), will warn and keep the existing description.

value

The new description, as a character string.

Details

The Description is recommended for discovery in DataCite. It captures additional information that does not fit other metadata categories <U+2014> such as technical notes or dataset usage. It is a free-text field. See dct:description.

Value

The Description attribute as a character vector of length 1.

See Also

Other bibliographic helper functions: contributor(), creator(), dataset_format(), dataset_title(), geolocation(), get_bibentry(), language(), publication_year(), publisher(), relation(), rights(), subject()

Examples

description(orange_df)
description(orange_df, overwrite = TRUE) <- "This dataset records orange tree growth."
description(orange_df)


dataset documentation built on June 3, 2026, 5:07 p.m.